function edit_TempPath_Callback(hObject, eventdata, handles)
% hObject    handle to edit_TempPath (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_TempPath as text
%        str2double(get(hObject,'String')) returns contents of edit_TempPath as a double

end